@@ -23,3 +23,10 @@ def test_message_thread_to_profile():
     assert profile.age
     assert profile.age > 18
     assert isinstance(profile.rating, int)
+
+
+@util.use_cassette('user_count')
+def test_user_search_count():
+    search = User().search(count=1)
+    import ipdb; ipdb.set_trace()
+    assert len(User().search(count=1))
